Plots to produce for the specified Gradient Boosted Tree model. Use "" to avoid showing any plots (default). Options are ...
nrobs
Number of data points to show in scatter plots (-1 for all)
incl
Which variables to include in a coefficient plot or PDP plot
incl_int
Which interactions to investigate in PDP plots
hline
Add a dashed horizontal line at the mean response (TRUE/FALSE or a numeric value)
pdp_range
Numeric vector c(lo, hi) giving the percentile range for PDP/Prediction plot x-axes (default c(0.025, 0.975))
minq
Deprecated. Use pdp_range[1] instead
maxq
Deprecated. Use pdp_range[2] instead
shiny
Did the function call originate inside a shiny app
custom
Logical (TRUE, FALSE) to indicate if ggplot object (or list of ggplot objects) should be returned.
This option can be used to customize plots (e.g., add a title, change x and y labels, etc.).
See examples and https://ggplot2.tidyverse.org for options.