Plot method for the rforest function
# S3 method for rforest
plot(
x,
plots = "",
nrobs = Inf,
incl = NULL,
incl_int = NULL,
hline = TRUE,
pdp_range = c(0.025, 0.975),
minq = NULL,
maxq = NULL,
shiny = FALSE,
custom = FALSE,
...
)Return value from rforest
Plots to produce for the specified Random Forest model. Use "" to avoid showing any plots (default). Options are ...
Number of data points to show in dashboard scatter plots (-1 for all)
Which variables to include in PDP or Prediction plots
Which interactions to investigate in PDP or Prediction plots
Add a dashed horizontal line at the mean response (TRUE/FALSE or a numeric value)
Numeric vector c(lo, hi) giving the percentile range for PDP/Prediction plot x-axes (default c(0.025, 0.975))
Deprecated. Use pdp_range[1] instead
Deprecated. Use pdp_range[2] instead
Did the function call originate inside a shiny app
Logical (TRUE, FALSE) to indicate if ggplot object (or list of ggplot objects) should be returned. This option can be used to customize plots (e.g., add a title, change x and y labels, etc.). See examples and https://ggplot2.tidyverse.org for options.
further arguments passed to or from other methods
See https://radiant-rstats.github.io/docs/model/rforest.html for an example in Radiant
rforest to generate results
summary.rforest to summarize results
predict.rforest for prediction
result <- rforest(titanic, "survived", c("pclass", "sex"), lev = "Yes")
Run the code above in your browser using DataLab