Create Partial Dependence Plots
pdp_plot(
x,
plot_list = list(),
incl,
incl_int,
fix = TRUE,
hline = TRUE,
nr = 20,
pdp_range = c(0.025, 0.975),
minq = NULL,
maxq = NULL
)Return value from a model
List used to store plots
Which variables to include in PDP plots
Which interactions to investigate in PDP plots
Set the desired limited on yhat or have it calculated automatically. Set to FALSE to have y-axis limits set by ggplot2 for each plot
Add a dashed horizontal line at the mean response. Set to FALSE to suppress, or a numeric value to draw the line at that specific value
Number of values to use to generate predictions for a numeric explanatory variable
Numeric vector c(lo, hi) giving the percentile range used to trim the
x-axis for numeric predictors (default c(0.025, 0.975))
Deprecated. Use pdp_range[1] instead
Deprecated. Use pdp_range[2] instead