Plot method for the nn function
# S3 method for nn
plot(
x,
plots = "vip",
size = 12,
pad_x = 0.9,
nrobs = -1,
incl = NULL,
incl_int = NULL,
hline = TRUE,
pdp_range = c(0.025, 0.975),
minq = NULL,
maxq = NULL,
shiny = FALSE,
custom = FALSE,
...
)Return value from nn
Plots to produce for the specified Neural Network model. Use "" to avoid showing any plots (default). Options are "olden" or "garson" for importance plots, or "net" to depict the network structure
Font size used
Padding for explanatory variable labels in the network plot. Default value is 0.9, smaller numbers (e.g., 0.5) increase the amount of padding
Number of data points to show in dashboard scatter plots (-1 for all)
Which variables to include in a coefficient plot or PDP plot
Which interactions to investigate in PDP plots
Add a dashed horizontal line at the mean response (TRUE/FALSE or a numeric value)
Numeric vector c(lo, hi) giving the percentile range for PDP/Prediction plot x-axes (default c(0.025, 0.975))
Deprecated. Use pdp_range[1] instead
Deprecated. Use pdp_range[2] instead
Did the function call originate inside a shiny app
Logical (TRUE, FALSE) to indicate if ggplot object (or list of ggplot objects) should be returned. This option can be used to customize plots (e.g., add a title, change x and y labels, etc.). See examples and https://ggplot2.tidyverse.org for options.
further arguments passed to or from other methods
See https://radiant-rstats.github.io/docs/model/nn.html for an example in Radiant
nn to generate results
summary.nn to summarize results
predict.nn for prediction
result <- nn(titanic, "survived", c("pclass", "sex"), lev = "Yes")
plot(result, plots = "net")
plot(result, plots = "olden")
Run the code above in your browser using DataLab